@@ -18,11 +18,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+import gettext
 import os
 import shutil
 
 from gi.repository import GObject, GLib, Eog, Gio, Gtk, PeasGtk
 
+_ = gettext.translation('eog-plugins', fallback=True).gettext
+
 _MENU_ID = 'Export'
 _ACTION_NAME = 'export-to-folder'
 
